@@ -14,7 +14,7 @@
     <message>
         <location filename="../src/filecontrol.cpp" line="793"/>
         <source>Extract text</source>
-        <translation type="unfinished"/>
+        <translation>استخراج النص</translation>
     </message>
     <message>
         <location filename="../src/filecontrol.cpp" line="797"/>
@@ -28,7 +28,6 @@
     </message>
     <message>
         <location filename="../src/filecontrol.cpp" line="805"/>
-        <location filename="../src/filecontrol.cpp" line="897"/>
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
@@ -60,7 +59,7 @@
     <message>
         <location filename="../src/filecontrol.cpp" line="829"/>
         <source>Image info</source>
-        <translation>Información d&apos;imaxe</translation>
+        <translation>Información d'imaxe</translation>
     </message>
     <message>
         <location filename="../src/filecontrol.cpp" line="833"/>
@@ -75,17 +74,17 @@
     <message>
         <location filename="../src/filecontrol.cpp" line="841"/>
         <source>Zoom in</source>
-        <translation type="unfinished"/>
+        <translation>تكبير</translation>
     </message>
     <message>
         <location filename="../src/filecontrol.cpp" line="845"/>
         <source>Zoom out</source>
-        <translation type="unfinished"/>
+        <translation>تصغير</translation>
     </message>
     <message>
         <location filename="../src/filecontrol.cpp" line="849"/>
         <source>Open</source>
-        <translation type="unfinished"/>
+        <translation>فتح</translation>
     </message>
     <message>
         <location filename="../src/filecontrol.cpp" line="853"/>
@@ -95,7 +94,7 @@
     <message>
         <location filename="../src/filecontrol.cpp" line="877"/>
         <source>Image Viewing</source>
-        <translation>Visión d&apos;imáxenes</translation>
+        <translation>Visión d'imáxenes</translation>
     </message>
     <message>
         <location filename="../src/filecontrol.cpp" line="881"/>
@@ -115,12 +114,12 @@
     <message>
         <location filename="../src/filecontrol.cpp" line="901"/>
         <source>Select all</source>
-        <translation type="unfinished"/>
+        <translation>اختر الكل</translation>
     </message>
     <message>
         <location filename="../src/filecontrol.cpp" line="909"/>
         <source>Live Text</source>
-        <translation type="unfinished"/>
+        <translation>النص الحي</translation>
     </message>
 </context>
 <context>
@@ -128,17 +127,17 @@
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="74"/>
         <source>Basic info</source>
-        <translation type="unfinished"/>
+        <translation>المعلومات الأساسية</translation>
     </message>
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="98"/>
         <source>Size</source>
-        <translation type="unfinished"/>
+        <translation>الحجم</translation>
     </message>
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="124"/>
         <source>Date captured</source>
-        <translation type="unfinished"/>
+        <translation>تاريخ التقاط الصورة</translation>
     </message>
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="131"/>
@@ -148,7 +147,7 @@
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="141"/>
         <source>Details</source>
-        <translation type="unfinished"/>
+        <translation>التفاصيل</translation>
     </message>
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="154"/>
@@ -158,7 +157,7 @@
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="162"/>
         <source>Exposure program</source>
-        <translation>Programa d&apos;esposición</translation>
+        <translation>Programa d'esposición</translation>
     </message>
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="169"/>
@@ -173,12 +172,12 @@
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="182"/>
         <source>Exposure mode</source>
-        <translation>Mou d&apos;esposición</translation>
+        <translation>Mou d'esposición</translation>
     </message>
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="188"/>
         <source>Exposure time</source>
-        <translation>Tiempu d&apos;esposición</translation>
+        <translation>Tiempu d'esposición</translation>
     </message>
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="194"/>
@@ -213,12 +212,12 @@
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="87"/>
         <source>File name</source>
-        <translation type="unfinished"/>
+        <translation>اسم الملف</translation>
     </message>
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="105"/>
         <source>Dimensions</source>
-        <translation type="unfinished"/>
+        <translation>الأبعاد</translation>
     </message>
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="112"/>
@@ -233,7 +232,7 @@
     <message>
         <location filename="../qml/InformationDialog/InformationDialog.qml" line="239"/>
         <source>Device model</source>
-        <translation type="unfinished"/>
+        <translation>نموذج الجهاز</translation>
     </message>
 </context>
 <context>
@@ -241,12 +240,12 @@
     <message>
         <location filename="../qml/LiveText/LiveTextWidget.qml" line="155"/>
         <source>Copy (Ctrl+C)</source>
-        <translation type="unfinished"/>
+        <translation>نسخ (Ctrl+C)</translation>
     </message>
     <message>
         <location filename="../qml/LiveText/LiveTextWidget.qml" line="172"/>
         <source>Select all (Ctrl+A)</source>
-        <translation type="unfinished"/>
+        <translation>اختر الكل (Ctrl+A)</translation>
     </message>
 </context>
 <context>
@@ -254,7 +253,7 @@
     <message>
         <location filename="../qml/MainStack.qml" line="127"/>
         <source>Select pictures</source>
-        <translation type="unfinished"/>
+        <translation>اختر الصور</translation>
     </message>
 </context>
 <context>
@@ -262,7 +261,7 @@
     <message>
         <location filename="../qml/ImageDelegate/NonexistImageDelegate.qml" line="43"/>
         <source>Image file not found</source>
-        <translation type="unfinished"/>
+        <translation>لم يتم العثور على ملف الصورة</translation>
     </message>
 </context>
 <context>
@@ -270,7 +269,7 @@
     <message>
         <location filename="../qml/OpenImageWidget.qml" line="35"/>
         <source>Open Image</source>
-        <translation type="unfinished"/>
+        <translation>فتح الصورة</translation>
     </message>
 </context>
 <context>
@@ -278,7 +277,7 @@
     <message>
         <location filename="../qml/InformationDialog/PropertyActionItemDelegate.qml" line="95"/>
         <source>The file already exists, please use another name</source>
-        <translation type="unfinished"/>
+        <translation>الملف موجود بالفعل، الرجاء استخدام اسمًا مختلفًا</translation>
     </message>
 </context>
 <context>
@@ -286,17 +285,17 @@
     <message>
         <location filename="../main.cpp" line="48"/>
         <source>Image Viewer</source>
-        <translation>Visor d&apos;imáxenes</translation>
+        <translation>Visor d'imáxenes</translation>
     </message>
     <message>
         <location filename="../src/unionimage/unionimage_global.h" line="102"/>
         <source>day</source>
-        <translation type="unfinished"/>
+        <translation>يوم</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="51"/>
         <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
-        <translation type="unfinished"/>
+        <translation>مُعاينة الصور هي أداة عرض الصور بواجهة أنيقة وعملية سلسة.</translation>
     </message>
 </context>
 <context>
@@ -304,12 +303,12 @@
     <message>
         <location filename="../qml/ReName.qml" line="70"/>
         <source>Input a new name</source>
-        <translation type="unfinished"/>
+        <translation>أدخل اسمًا جديدًا</translation>
     </message>
     <message>
         <location filename="../qml/ReName.qml" line="85"/>
         <source>The file already exists, please use another name</source>
-        <translation type="unfinished"/>
+        <translation>تأكيد</translation>
     </message>
     <message>
         <location filename="../qml/ReName.qml" line="141"/>
@@ -319,20 +318,20 @@
     <message>
         <location filename="../qml/ReName.qml" line="123"/>
         <source>Confirm</source>
-        <translation type="unfinished"/>
+        <translation>لا يمكن نقل "%1" إلى سلة المهملات. هل ترغب في حذفه بشكل دائم؟</translation>
     </message>
 </context>
 <context>
     <name>RemoveDialog</name>
     <message>
         <location filename="../qml/Dialog/RemoveDialog.qml" line="71"/>
-        <source>Cannot move &quot;%1&quot; to the trash. Do you want to permanently delete it?</source>
-        <translation type="unfinished"/>
+        <source>Cannot move "%1" to the trash. Do you want to permanently delete it?</source>
+        <translation>لا يمكن إلغاء هذه العملية</translation>
     </message>
     <message>
         <location filename="../qml/Dialog/RemoveDialog.qml" line="89"/>
         <source>This action cannot be undone</source>
-        <translation type="unfinished"/>
+        <translation>الإيقاف المؤقت</translation>
     </message>
     <message>
         <location filename="../qml/Dialog/RemoveDialog.qml" line="101"/>
@@ -342,7 +341,7 @@
     <message>
         <location filename="../qml/Dialog/RemoveDialog.qml" line="111"/>
         <source>Confirm</source>
-        <translation type="unfinished"/>
+        <translation>تشغيل</translation>
     </message>
 </context>
 <context>
@@ -354,15 +353,13 @@
     </message>
     <message>
         <location filename="../qml/SliderShow.qml" line="172"/>
-        <location filename="../qml/SliderShow.qml" line="223"/>
         <source>Pause</source>
-        <translation type="unfinished"/>
+        <translation>الحجم الأصلي</translation>
     </message>
     <message>
         <location filename="../qml/SliderShow.qml" line="172"/>
-        <location filename="../qml/SliderShow.qml" line="223"/>
         <source>Play</source>
-        <translation type="unfinished"/>
+        <translation>Reproducir</translation>
     </message>
     <message>
         <location filename="../qml/SliderShow.qml" line="188"/>
@@ -371,7 +368,6 @@
     </message>
     <message>
         <location filename="../qml/SliderShow.qml" line="203"/>
-        <location filename="../qml/SliderShow.qml" line="244"/>
         <source>Exit</source>
         <translation>Colar</translation>
     </message>
@@ -391,7 +387,7 @@
     <message>
         <location filename="../qml/ThumbnailListView.qml" line="209"/>
         <source>Original size</source>
-        <translation type="unfinished"/>
+        <translation>Tamañu original</translation>
     </message>
     <message>
         <location filename="../qml/ThumbnailListView.qml" line="228"/>
@@ -401,12 +397,12 @@
     <message>
         <location filename="../qml/ThumbnailListView.qml" line="246"/>
         <source>Rotate</source>
-        <translation type="unfinished"/>
+        <translation>Girar</translation>
     </message>
     <message>
         <location filename="../qml/ThumbnailListView.qml" line="519"/>
         <source>Extract text</source>
-        <translation type="unfinished"/>
+        <translation>Extraer texto</translation>
     </message>
     <message>
         <location filename="../qml/ThumbnailListView.qml" line="538"/>
@@ -434,7 +430,7 @@
     <message>
         <location filename="../qml/ViewRightMenu.qml" line="76"/>
         <source>Extract text</source>
-        <translation type="unfinished"/>
+        <translation>Extraer texto</translation>
     </message>
     <message>
         <location filename="../qml/ViewRightMenu.qml" line="96"/>
@@ -489,7 +485,7 @@
     <message>
         <location filename="../qml/ViewRightMenu.qml" line="280"/>
         <source>Image info</source>
-        <translation>Información d&apos;imaxe</translation>
+        <translation>Información d'imaxe</translation>
     </message>
 </context>
 <context>
@@ -497,25 +493,25 @@
     <message>
         <location filename="../qml/ViewTopTitle.qml" line="184"/>
         <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
-        <translation type="unfinished"/>
+        <translation>Image Viewer ye un herramienta pa visualizar imáxenes con interfaz moderna y rendimientu suave.</translation>
     </message>
     <message>
         <location filename="../qml/ViewTopTitle.qml" line="186"/>
         <source>Image Viewer</source>
-        <translation>Visor d&apos;imáxenes</translation>
+        <translation>Visor d'imáxenes</translation>
     </message>
     <message>
         <source>Version</source>
-        <translation type="unfinished"/>
+        <translation>Versión</translation>
     </message>
     <message>
         <source>%1 is released under %2</source>
-        <translation type="unfinished"/>
+        <translation>'%1 foi liberada baixo %2'</translation>
     </message>
     <message>
         <location filename="../qml/ViewTopTitle.qml" line="162"/>
         <source>Open image</source>
-        <translation type="unfinished"/>
+        <translation>Abrir imaxe</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
